0.3 (2019-02-27)
----------------

- Added support for showing data on the surface of celestial bodies as well as
  in the 3D Solar System/Milky Way/Universe view. [#40, #42]

- Added support for color-coding and changing point size based on attributes
  (requires PyWWT 0.6 or later). [#44]

0.2 (2018-12-29)
----------------

- Add a Save button to save the current view to a file. [#38]

- Make use of PyWWT. [#32, #35]

- Change default foreground and background imagery. [#29]

- Fix compatibility with latest version of glue. [#25]

- Allow world coordinates to be used for the RA/Dec. [#21]

0.1 (2017-08-23)
----------------

- Initial release
